summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor/utils.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/formeditor/utils.h')
-rw-r--r--kexi/formeditor/utils.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kexi/formeditor/utils.h b/kexi/formeditor/utils.h
index d6d56acb..3d078401 100644
--- a/kexi/formeditor/utils.h
+++ b/kexi/formeditor/utils.h
@@ -71,22 +71,22 @@ typedef TQPtrListIterator<TQWidget> WidgetListIterator;
class HorWidgetList : public WidgetList
{
public:
- HorWidgetList(TQWidget *topLevelWidget);
+ HorWidgetList(TQWidget *tqtopLevelWidget);
virtual ~HorWidgetList();
protected:
virtual int compareItems(TQPtrCollection::Item item1, TQPtrCollection::Item item2);
- TQWidget *m_topLevelWidget;
+ TQWidget *m_tqtopLevelWidget;
};
//! @short A helper for sorting widgets vertically
class VerWidgetList : public WidgetList
{
public:
- VerWidgetList(TQWidget *topLevelWidget);
+ VerWidgetList(TQWidget *tqtopLevelWidget);
virtual ~VerWidgetList();
protected:
virtual int compareItems(TQPtrCollection::Item item1, TQPtrCollection::Item item2);
- TQWidget *m_topLevelWidget;
+ TQWidget *m_tqtopLevelWidget;
};
/*! This function is used to remove all the child widgets from a list, and
@@ -94,18 +94,18 @@ class VerWidgetList : public WidgetList
KFORMEDITOR_EXPORT void removeChildrenFromList(WidgetList &list);
/*! This helper function install an event filter on \a object and all of its
- children, directed to \a container.
+ tqchildren, directed to \a container.
This is necessary to filter events for composed widgets. */
KFORMEDITOR_EXPORT void installRecursiveEventFilter(TQObject *object, TQObject *container);
/*! This helper function removes an event filter installed before
- on \a object and all of its children.
+ on \a object and all of its tqchildren.
This is necessary to filter events for composed widgets. */
KFORMEDITOR_EXPORT void removeRecursiveEventFilter(TQObject *object, TQObject *container);
KFORMEDITOR_EXPORT void setRecursiveCursor(TQWidget *w, Form *form);
/*! \return the size of \a w children. This can be used eg to get widget's sizeHint. */
KFORMEDITOR_EXPORT TQSize getSizeFromChildren(TQWidget *widget, const char *inheritClass=TQWIDGET_OBJECT_NAME_STRING);
}
@@ -94,18 +94,18 @@ class VerWidgetList : public WidgetList
KFORMEDITOR_EXPORT void removeRecursiveEventFilter(TQObject *object, TQObject *container);
KFORMEDITOR_EXPORT void setRecursiveCursor(TQWidget *w, Form *form);
-/*! \return the size of \a w children. This can be used eg to get widget's sizeHint. */
+/*! \return the size of \a w tqchildren. This can be used eg to get widget's tqsizeHint. */
KFORMEDITOR_EXPORT TQSize getSizeFromChildren(TQWidget *widget, const char *inheritClass=TQWIDGET_OBJECT_NAME_STRING);
}